==> DateTime-Locale-1.20.tar.gz: DateTime-Locale-1.20/share/mfe-MU.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "M",
    MEd => "MM-dd, E",
    MMM => "MMM",
    MMMEd => "E d MMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMd => "d/MM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMM => "MM/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "mfe-MU",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "lin",
    "mar",
    "mer",
    "ze",
    "van",
    "sam",
    "dim",
  ],
  day_format_narrow => [
    "l",
    "m",
    "m",
    "z",
    "v",
    "s",
    "d",
  ],
  day_format_wide => [
    "lindi",
    "mardi",
    "merkredi",
    "zedi",
    "vandredi",
    "samdi",
    "dimans",
  ],
  day_stand_alone_abbreviated => [
    "lin",
    "mar",
    "mer",
    "ze",
    "van",
    "sam",
    "dim",
  ],
  day_stand_alone_narrow => [
    "l",
    "m",
    "m",
    "z",
    "v",
    "s",
    "d",
  ],
  day_stand_alone_wide => [
    "lindi",
    "mardi",
    "merkredi",
    "zedi",
    "vandredi",
    "samdi",
    "dimans",
  ],
  era_abbreviated => [
    "av. Z-K",
    "ap. Z-K",
  ],
  era_narrow => [
    "av. Z-K",
    "ap. Z-K",
  ],
  era_wide => [
    "avan Zezi-Krist",
    "apre Zezi-Krist",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Morisyen",
  month_format_abbreviated => [
    "zan",
    "fev",
    "mar",
    "avr",
    "me",
    "zin",
    "zil",
    "out",
    "sep",
    "okt",
    "nov",
    "des",
  ],
  month_format_narrow => [
    "z",
    "f",
    "m",
    "a",
    "m",
    "z",
    "z",
    "o",
    "s",
    "o",
    "n",
    "d",
  ],
  month_format_wide => [
    "zanvie",
    "fevriye",
    "mars",
    "avril",
    "me",
    "zin",
    "zilye",
    "out",
    "septam",
    "oktob",
    "novam",
    "desam",
  ],
  month_stand_alone_abbreviated => [
    "zan",
    "fev",
    "mar",
    "avr",
    "me",
    "zin",
    "zil",
    "out",
    "sep",
    "okt",
    "nov",
    "des",
  ],
  month_stand_alone_narrow => [
    "z",
    "f",
    "m",
    "a",
    "m",
    "z",
    "z",
    "o",
    "s",
    "o",
    "n",
    "d",
  ],
  month_stand_alone_wide => [
    "zanvie",
    "fevriye",
    "mars",
    "avril",
    "me",
    "zin",
    "zilye",
    "out",
    "septam",
    "oktob",
    "novam",
    "desam",
  ],
  name => "Morisyen Mauritius",
  native_language => "kreol morisien",
  native_name => "kreol morisien Moris",
  native_script => undef,
  native_territory => "Moris",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1e trimes",
    "2em trimes",
    "3em trimes",
    "4em trimes",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1e trimes",
    "2em trimes",
    "3em trimes",
    "4em trimes",
  ],
  script => undef,
  territory => "Mauritius",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 33,
}

==> DateTime-Locale-1.28.tar.gz: DateTime-Locale-1.28/share/mfe-MU.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "M",
    MEd => "MM-dd, E",
    MMM => "MMM",
    MMMEd => "E d MMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMd => "d/MM",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMM => "MM/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "mfe-MU",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "lin",
    "mar",
    "mer",
    "ze",
    "van",
    "sam",
    "dim",
  ],
  day_format_narrow => [
    "l",
    "m",
    "m",
    "z",
    "v",
    "s",
    "d",
  ],
  day_format_wide => [
    "lindi",
    "mardi",
    "merkredi",
    "zedi",
    "vandredi",
    "samdi",
    "dimans",
  ],
  day_stand_alone_abbreviated => [
    "lin",
    "mar",
    "mer",
    "ze",
    "van",
    "sam",
    "dim",
  ],
  day_stand_alone_narrow => [
    "l",
    "m",
    "m",
    "z",
    "v",
    "s",
    "d",
  ],
  day_stand_alone_wide => [
    "lindi",
    "mardi",
    "merkredi",
    "zedi",
    "vandredi",
    "samdi",
    "dimans",
  ],
  era_abbreviated => [
    "av. Z-K",
    "ap. Z-K",
  ],
  era_narrow => [
    "av. Z-K",
    "ap. Z-K",
  ],
  era_wide => [
    "avan Zezi-Krist",
    "apre Zezi-Krist",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %e %b %H:%M:%S %Z %Y",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "%a %d %b %Y %T %Z",
  glibc_time_12_format => "%l:%M:%S %P %Z",
  glibc_time_format => "%T",
  language => "Morisyen",
  month_format_abbreviated => [
    "zan",
    "fev",
    "mar",
    "avr",
    "me",
    "zin",
    "zil",
    "out",
    "sep",
    "okt",
    "nov",
    "des",
  ],
  month_format_narrow => [
    "z",
    "f",
    "m",
    "a",
    "m",
    "z",
    "z",
    "o",
    "s",
    "o",
    "n",
    "d",
  ],
  month_format_wide => [
    "zanvie",
    "fevriye",
    "mars",
    "avril",
    "me",
    "zin",
    "zilye",
    "out",
    "septam",
    "oktob",
    "novam",
    "desam",
  ],
  month_stand_alone_abbreviated => [
    "zan",
    "fev",
    "mar",
    "avr",
    "me",
    "zin",
    "zil",
    "out",
    "sep",
    "okt",
    "nov",
    "des",
  ],
  month_stand_alone_narrow => [
    "z",
    "f",
    "m",
    "a",
    "m",
    "z",
    "z",
    "o",
    "s",
    "o",
    "n",
    "d",
  ],
  month_stand_alone_wide => [
    "zanvie",
    "fevriye",
    "mars",
    "avril",
    "me",
    "zin",
    "zilye",
    "out",
    "septam",
    "oktob",
    "novam",
    "desam",
  ],
  name => "Morisyen Mauritius",
  native_language => "kreol morisien",
  native_name => "kreol morisien Moris",
  native_script => undef,
  native_territory => "Moris",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1e trimes",
    "2em trimes",
    "3em trimes",
    "4em trimes",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1e trimes",
    "2em trimes",
    "3em trimes",
    "4em trimes",
  ],
  script => undef,
  territory => "Mauritius",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 37,
}
